@@ -35,10 +35,12 @@ public:
 #ifdef WITH_DDCUTIL
     DDCutilDisplay(DDCA_Display_Ref, QMutex *openDisplayMutex);
     DDCA_IO_Path ioPath() const;
+    static QString generatePathId(const DDCA_IO_Path &displayPath);
 #endif
     ~DDCutilDisplay();
 
-    QString label() const;
+    QString id() const override;
+    QString label() const override;
     int knownSafeMinBrightness() const override;
     int maxBrightness() const override;
     int brightness() const override;
@@ -46,6 +48,7 @@ public:
     bool supportsBrightness() const;
     void resumeWorker();
     void pauseWorker();
+    std::optional<QByteArray> edidData() const override;
 
 Q_SIGNALS:
     void supportsBrightnessChanged(bool supportsBrightness);
@@ -60,6 +63,7 @@ private:
     DDCA_Display_Ref m_displayRef;
     DDCA_IO_Path m_ioPath;
 #endif
+    QString m_id;
     QString m_label;
     BrightnessWorker *m_brightnessWorker;
     QThread m_brightnessWorkerThread;
@@ -68,6 +72,7 @@ private:
     int m_brightness;
     int m_maxBrightness;
     bool m_supportsBrightness;
+    QByteArray m_edidData;
 };
 
 class BrightnessWorker : public QObject
