@@ -47,6 +47,8 @@
 #include <sys/timerfd.h>
 #endif
 
+using namespace Qt::StringLiterals;
+
 namespace PowerDevil
 {
 Core::Core(QObject *parent)
@@ -89,7 +91,8 @@ void Core::loadCore()
     m_screenBrightnessController = std::make_unique<ScreenBrightnessController>();
 
     connect(m_screenBrightnessController.get(), &ScreenBrightnessController::detectionFinished, this, &Core::onControllersReady);
-    connect(m_screenBrightnessController.get(), &ScreenBrightnessController::supportedChanged, this, &Core::refreshActions);
+    connect(m_screenBrightnessController.get(), &ScreenBrightnessController::displayAdded, this, &Core::refreshActions);
+    connect(m_screenBrightnessController.get(), &ScreenBrightnessController::displayRemoved, this, &Core::refreshActions);
     m_screenBrightnessController->detectDisplays();
 }
 
@@ -130,7 +133,7 @@ void Core::onControllersReady()
     });
 
     // Set up the policy agent
-    PowerDevil::PolicyAgent::instance()->init();
+    PowerDevil::PolicyAgent::instance()->init(m_globalSettings);
     // When inhibitions change, simulate user activity, see Bug 315438
     connect(PowerDevil::PolicyAgent::instance(),
             &PowerDevil::PolicyAgent::unavailablePoliciesChanged,
@@ -453,7 +456,7 @@ void Core::onDeviceAdded(const QString &udi)
             m_criticalBatteryTimer->stop();
             emitRichNotification(QStringLiteral("pluggedin"), //
                                  i18n("Extra Battery Added"),
-                                 i18n("The computer will no longer go to sleep."));
+                                 i18n("The system will no longer go to sleep."));
         }
     }
 }
@@ -581,9 +584,9 @@ void Core::handleLowBattery(int percent)
     m_lowBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
     updateBatteryNotifications(percent); // sets title
     if (m_batteryController->acAdapterState() == BatteryController::Plugged) {
-        m_lowBatteryNotification->setText(i18n("Ensure that the power adapter is plugged in and provides enough power."));
+        m_lowBatteryNotification->setText(i18n("Ensure that the power cord is plugged in all the way and provides enough power."));
     } else {
-        m_lowBatteryNotification->setText(i18n("Plug in the computer."));
+        m_lowBatteryNotification->setText(i18n("Plug in the power cord."));
     }
     m_lowBatteryNotification->setUrgency(KNotification::CriticalUrgency);
     m_lowBatteryNotification->sendEvent();
@@ -602,7 +605,7 @@ void Core::handleCriticalBattery(int percent)
 
     switch (static_cast<PowerButtonAction>(m_globalSettings->batteryCriticalAction())) {
     case PowerButtonAction::Shutdown: {
-        m_criticalBatteryNotification->setText(i18n("Battery level critical. Your computer will shut down in 60 seconds."));
+        m_criticalBatteryNotification->setText(i18n("The system will shut down in 60 seconds."));
         auto action =
             m_criticalBatteryNotification->addAction(i18nc("@action:button Shut down without waiting for the battery critical timer", "Shut Down Now"));
         connect(action, &KNotificationAction::activated, this, &Core::triggerCriticalBatteryAction);
@@ -610,7 +613,7 @@ void Core::handleCriticalBattery(int percent)
         break;
     }
     case PowerButtonAction::Hibernate: {
-        m_criticalBatteryNotification->setText(i18n("Battery level critical. Your computer will enter hibernation mode in 60 seconds."));
+        m_criticalBatteryNotification->setText(i18n("The system will hibernate in 60 seconds."));
         auto action = m_criticalBatteryNotification->addAction(
             i18nc("@action:button Enter hibernation mode without waiting for the battery critical timer", "Hibernate Now"));
         connect(action, &KNotificationAction::activated, this, &Core::triggerCriticalBatteryAction);
@@ -618,7 +621,7 @@ void Core::handleCriticalBattery(int percent)
         break;
     }
     case PowerButtonAction::Sleep: {
-        m_criticalBatteryNotification->setText(i18n("Battery level critical. Your computer will go to sleep in 60 seconds."));
+        m_criticalBatteryNotification->setText(i18n("The system will go to sleep in 60 seconds."));
         auto action =
             m_criticalBatteryNotification->addAction(i18nc("@action:button Suspend to ram without waiting for the battery critical timer", "Sleep Now"));
         connect(action, &KNotificationAction::activated, this, &Core::triggerCriticalBatteryAction);
@@ -672,13 +675,13 @@ void Core::onAcAdapterStateChanged(BatteryController::AcAdapterState state)
         if (m_criticalBatteryTimer->isActive()) {
             m_criticalBatteryTimer->stop();
             emitRichNotification(QStringLiteral("pluggedin"), //
-                                 i18n("AC Adapter Plugged In"),
+                                 i18n("Power Cord Plugged In"),
                                  i18n("The computer will no longer go to sleep."));
         } else {
-            emitRichNotification(QStringLiteral("pluggedin"), i18n("Running on AC power"), i18n("The power adapter has been plugged in."));
+            emitRichNotification(QStringLiteral("pluggedin"), i18n("Running on AC power"), i18n("The power cord has been plugged in."));
         }
     } else if (state == BatteryController::Unplugged) {
-        emitRichNotification(QStringLiteral("unplugged"), i18n("Running on Battery Power"), i18n("The power adapter has been unplugged."));
+        emitRichNotification(QStringLiteral("unplugged"), i18n("Running on Battery Power"), i18n("The power cord has been unplugged."));
     }
 }
 
@@ -1045,10 +1048,10 @@ uint Core::scheduleWakeup(const QString &service, const QDBusObjectPath &path, q
     int cookie = m_lastWakeupCookie;
     // if some one is trying to time travel, deny them
     if (timeout < QDateTime::currentSecsSinceEpoch()) {
-        sendErrorReply(QDBusError::InvalidArgs, "You can not schedule wakeup in past");
+        sendErrorReply(QDBusError::InvalidArgs, u"You can not schedule wakeup in past"_s);
     } else {
 #ifndef Q_OS_LINUX
-        sendErrorReply(QDBusError::NotSupported, "Scheduled wakeups are available only on Linux platforms");
+        sendErrorReply(QDBusError::NotSupported, u"Scheduled wakeups are available only on Linux platforms"_s);
 #else
         WakeupInfo wakeup{service, path, cookie, timeout};
         m_scheduledWakeups << wakeup;
@@ -1067,7 +1070,7 @@ void Core::wakeup()
         QVariantMap args;
         // we pass empty string as type because when empty type is passed,
         // it turns screen on.
-        args[QStringLiteral("Type")] = "";
+        args[u"Type"_s] = QString();
         helperAction->trigger(args);
     }
 }
@@ -1090,7 +1093,7 @@ void Core::clearWakeup(int cookie)
                              m_scheduledWakeups.end());
 
     if (oldListSize == m_scheduledWakeups.size()) {
-        sendErrorReply(QDBusError::InvalidArgs, "Can not clear the invalid wakeup");
+        sendErrorReply(QDBusError::InvalidArgs, u"Can not clear the invalid wakeup"_s);
         return;
     }
 
